@@ -23,15 +23,21 @@ import (
 
 	"github.com/apache/camel-k/v2/addons/strimzi/duck/client/internalclientset"
 	"github.com/apache/camel-k/v2/addons/strimzi/duck/v1beta2"
-
 	camelv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	camelv1alpha1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1alpha1"
 	"github.com/apache/camel-k/v2/pkg/util/bindings"
 	"github.com/apache/camel-k/v2/pkg/util/uri"
+	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
 
+// camelKafka represent the configuration required by Camel Kafka component.
+type camelKafka struct {
+	topicName  string
+	properties map[string]string
+}
+
 // BindingProvider allows to connect to a Kafka topic via Binding.
 type BindingProvider struct {
 	Client internalclientset.Interface
@@ -43,27 +49,53 @@ func (s BindingProvider) ID() string {
 
 func (s BindingProvider) Translate(ctx bindings.BindingContext, _ bindings.EndpointContext, endpoint camelv1.Endpoint) (*bindings.Binding, error) {
 	if endpoint.Ref == nil {
-		// React only on refs
+		// IMPORTANT: just pass through if this provider cannot manage the binding. Another provider in the chain may take care or it.
 		return nil, nil
 	}
 	gv, err := schema.ParseGroupVersion(endpoint.Ref.APIVersion)
 	if err != nil {
 		return nil, err
 	}
-
-	if gv.Group != v1beta2.StrimziGroup || endpoint.Ref.Kind != v1beta2.StrimziKindTopic {
-		// Only operates on Strimzi Topics
+	if gv.Group != v1beta2.StrimziGroup {
+		// IMPORTANT: just pass through if this provider cannot manage the binding. Another provider in the chain may take care or it.
 		return nil, nil
 	}
 
+	camelKafka, err := s.toCamelKafka(ctx, endpoint)
+	if err != nil {
+		return nil, err
+	}
+	kafkaURI := fmt.Sprintf("kafka:%s", camelKafka.topicName)
+	kafkaURI = uri.AppendParameters(kafkaURI, camelKafka.properties)
+
+	return &bindings.Binding{
+		URI: kafkaURI,
+	}, nil
+}
+
+// toCamelKafka serialize an endpoint to a camelKafka struct.
+func (s BindingProvider) toCamelKafka(ctx bindings.BindingContext, endpoint camelv1.Endpoint) (*camelKafka, error) {
+	switch endpoint.Ref.Kind {
+	case v1beta2.StrimziKindKafkaCluster:
+		return s.fromKafkaToCamel(ctx, endpoint)
+	case v1beta2.StrimziKindTopic:
+		return s.fromKafkaTopicToCamel(ctx, endpoint)
+	}
+
+	return nil, fmt.Errorf("invalid endpoint kind. Can only work with %s or %s kind", v1beta2.StrimziKindKafkaCluster, v1beta2.StrimziKindTopic)
+}
+
+// Verify and transform a Kafka resource to Camel Kafka endpoint parameters.
+func (s BindingProvider) fromKafkaToCamel(ctx bindings.BindingContext, endpoint camelv1.Endpoint) (*camelKafka, error) {
 	props, err := endpoint.Properties.GetPropertyMap()
 	if err != nil {
 		return nil, err
 	}
-	if props == nil {
-		props = make(map[string]string)
+	if props == nil || props["topic"] == "" {
+		return nil, fmt.Errorf("invalid endpoint configuration: missing topic property")
 	}
-
+	topicName := props["topic"]
+	delete(props, "topic")
 	if props["brokers"] == "" {
 		// build the client if needed
 		if s.Client == nil {
@@ -73,31 +105,71 @@ func (s BindingProvider) Translate(ctx bindings.BindingContext, _ bindings.Endpo
 			}
 			s.Client = kafkaClient
 		}
-
-		// look them up
-		topic, err := s.Client.KafkaV1beta2().KafkaTopics(ctx.Namespace).Get(ctx.Ctx, endpoint.Ref.Name, v1.GetOptions{})
+		bootstrapServers, err := s.getBootstrapServers(ctx, endpoint.Ref.Name)
 		if err != nil {
 			return nil, err
 		}
+		props["brokers"] = bootstrapServers
+	}
 
+	return &camelKafka{
+		topicName:  topicName,
+		properties: props,
+	}, nil
+}
+
+// Verify and transform a KafkaTopic resource to Camel Kafka endpoint parameters.
+func (s BindingProvider) fromKafkaTopicToCamel(ctx bindings.BindingContext, endpoint camelv1.Endpoint) (*camelKafka, error) {
+	props, err := endpoint.Properties.GetPropertyMap()
+	if err != nil {
+		return nil, err
+	}
+	if props == nil {
+		props = make(map[string]string)
+	}
+	if props["brokers"] == "" {
+		// build the client if needed
+		if s.Client == nil {
+			kafkaClient, err := internalclientset.NewForConfig(ctx.Client.GetConfig())
+			if err != nil {
+				return nil, err
+			}
+			s.Client = kafkaClient
+		}
+		// look them up: first, look at the CR name
+		topic, err := s.Client.KafkaV1beta2().KafkaTopics(ctx.Namespace).Get(ctx.Ctx, endpoint.Ref.Name, v1.GetOptions{})
+		if err != nil {
+			if k8serrors.IsNotFound(err) {
+				// if not found, then, look at the .status.topicName (it may be autogenerated)
+				topicList, err := s.Client.KafkaV1beta2().KafkaTopics(ctx.Namespace).List(ctx.Ctx, v1.ListOptions{
+					FieldSelector: "status.topicName=" + endpoint.Ref.Name,
+				})
+				if err != nil {
+					return nil, err
+				}
+				if len(topicList.Items) == 0 {
+					return nil, fmt.Errorf("couldn't find any KafkaTopic with either name or topicName %s", endpoint.Ref.Name)
+				}
+				// Just return the first item
+				topic = &topicList.Items[0]
+			} else {
+				return nil, err
+			}
+		}
 		clusterName := topic.Labels[v1beta2.StrimziKafkaClusterLabel]
 		if clusterName == "" {
 			return nil, fmt.Errorf("no %q label defined on topic %s", v1beta2.StrimziKafkaClusterLabel, endpoint.Ref.Name)
 		}
-
 		bootstrapServers, err := s.getBootstrapServers(ctx, clusterName)
 		if err != nil {
 			return nil, err
 		}
-
 		props["brokers"] = bootstrapServers
 	}
 
-	kafkaURI := fmt.Sprintf("kafka:%s", endpoint.Ref.Name)
-	kafkaURI = uri.AppendParameters(kafkaURI, props)
-
-	return &bindings.Binding{
-		URI: kafkaURI,
+	return &camelKafka{
+		topicName:  endpoint.Ref.Name,
+		properties: props,
 	}, nil
 }
 
@@ -108,16 +180,16 @@ func (s BindingProvider) getBootstrapServers(ctx bindings.BindingContext, cluste
 	}
 
 	for _, l := range cluster.Status.Listeners {
-		if l.Type == v1beta2.StrimziListenerTypePlain {
+		if l.Name == v1beta2.StrimziListenerNamePlain {
 			if l.BootstrapServers == "" {
-				return "", fmt.Errorf("cluster %q has no bootstrap servers in %q listener", clusterName, v1beta2.StrimziListenerTypePlain)
+				return "", fmt.Errorf("cluster %q has no bootstrap servers in %q listener", clusterName, v1beta2.StrimziListenerNamePlain)
 			}
 
 			return l.BootstrapServers, nil
 		}
 	}
 
-	return "", fmt.Errorf("cluster %q has no listeners of type %q", clusterName, v1beta2.StrimziListenerTypePlain)
+	return "", fmt.Errorf("cluster %q has no listeners of name %q", clusterName, v1beta2.StrimziListenerNamePlain)
 }
 
 // Order --.
@@ -208,16 +280,16 @@ func (s V1alpha1BindingProvider) getBootstrapServers(ctx bindings.V1alpha1Bindin
 	}
 
 	for _, l := range cluster.Status.Listeners {
-		if l.Type == v1beta2.StrimziListenerTypePlain {
+		if l.Name == v1beta2.StrimziListenerNamePlain {
 			if l.BootstrapServers == "" {
-				return "", fmt.Errorf("cluster %q has no bootstrap servers in %q listener", clusterName, v1beta2.StrimziListenerTypePlain)
+				return "", fmt.Errorf("cluster %q has no bootstrap servers in %q listener", clusterName, v1beta2.StrimziListenerNamePlain)
 			}
 
 			return l.BootstrapServers, nil
 		}
 	}
 
-	return "", fmt.Errorf("cluster %q has no listeners of type %q", clusterName, v1beta2.StrimziListenerTypePlain)
+	return "", fmt.Errorf("cluster %q has no listeners of type %q", clusterName, v1beta2.StrimziListenerNamePlain)
 }
 
 // Order --.
