@@ -23,7 +23,6 @@ package util
 import (
 	"bufio"
 	"context"
-	"errors"
 	"fmt"
 	"os"
 	"strings"
@@ -188,6 +187,21 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 		t.Logf("---\n%s\n---\n", string(pdata))
 	}
 
+	// IntegrationProfiles
+	iprs, err := camelClient.CamelV1().IntegrationProfiles(ns).List(ctx, metav1.ListOptions{})
+	if err != nil {
+		return err
+	}
+	t.Logf("Found %d integration profiles:\n", len(iprs.Items))
+	for _, p := range iprs.Items {
+		ref := p
+		pdata, err := kubernetes.ToYAMLNoManagedFields(&ref)
+		if err != nil {
+			return err
+		}
+		t.Logf("---\n%s\n---\n", string(pdata))
+	}
+
 	// CamelCatalogs
 	cats, err := camelClient.CamelV1().CamelCatalogs(ns).List(ctx, metav1.ListOptions{})
 	if err != nil {
@@ -244,7 +258,7 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 	// OLM CSV
 	csvs := olm.ClusterServiceVersionList{}
 	err = c.List(ctx, &csvs, ctrl.InNamespace(ns))
-	if err != nil {
+	if err != nil && !kubernetes.IsUnknownAPIError(err) {
 		return err
 	}
 	t.Logf("\nFound %d OLM CSVs:\n", len(csvs.Items))
@@ -258,18 +272,8 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 	}
 
 	// Some log from running pods
-
-	//
-	// Get logs for global operator if it is being used
-	//
-	globalTest := os.Getenv("CAMEL_K_FORCE_GLOBAL_TEST") == "true"
-	if globalTest {
-		opns := os.Getenv("CAMEL_K_GLOBAL_OPERATOR_NS")
-		if opns == "" {
-			err := errors.New("No operator namespace defined in CAMEL_K_GLOBAL_OPERATOR_NS")
-			t.Logf("ERROR cannot find global operator namespace: %v\n", err)
-		}
-
+	opns := os.Getenv("CAMEL_K_GLOBAL_OPERATOR_NS")
+	if opns != "" {
 		lst, err := c.CoreV1().Pods(opns).List(ctx, metav1.ListOptions{})
 		if err != nil {
 			return err
