@@ -63,10 +63,10 @@ func TestLanguageAlreadySet(t *testing.T) {
 func TestAddDependency(t *testing.T) {
 	integration := IntegrationSpec{}
 	integration.AddDependency("camel:file")
-	assert.Equal(t, integration.Dependencies, []string{"camel:file"})
+	assert.Equal(t, []string{"camel:file"}, integration.Dependencies)
 	// adding the same dependency twice won't duplicate it in the list
 	integration.AddDependency("camel:file")
-	assert.Equal(t, integration.Dependencies, []string{"camel:file"})
+	assert.Equal(t, []string{"camel:file"}, integration.Dependencies)
 
 	integration = IntegrationSpec{}
 	integration.AddDependency("mvn:com.my:company")
