@@ -27,7 +27,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
-// GetConditions --
+// GetConditions --.
 func (in *KameletStatus) GetConditions() []v1.ResourceCondition {
 	res := make([]v1.ResourceCondition, 0, len(in.Conditions))
 	for _, c := range in.Conditions {
@@ -36,32 +36,32 @@ func (in *KameletStatus) GetConditions() []v1.ResourceCondition {
 	return res
 }
 
-// GetType --
+// GetType --.
 func (c KameletCondition) GetType() string {
 	return string(c.Type)
 }
 
-// GetStatus --
+// GetStatus --.
 func (c KameletCondition) GetStatus() corev1.ConditionStatus {
 	return c.Status
 }
 
-// GetLastUpdateTime --
+// GetLastUpdateTime --.
 func (c KameletCondition) GetLastUpdateTime() metav1.Time {
 	return c.LastUpdateTime
 }
 
-// GetLastTransitionTime --
+// GetLastTransitionTime --.
 func (c KameletCondition) GetLastTransitionTime() metav1.Time {
 	return c.LastTransitionTime
 }
 
-// GetReason --
+// GetReason --.
 func (c KameletCondition) GetReason() string {
 	return c.Reason
 }
 
-// GetMessage --
+// GetMessage --.
 func (c KameletCondition) GetMessage() string {
 	return c.Message
 }
@@ -77,7 +77,7 @@ func (in *KameletStatus) GetCondition(condType KameletConditionType) *KameletCon
 	return nil
 }
 
-// SetCondition --
+// SetCondition --.
 func (in *KameletStatus) SetCondition(condType KameletConditionType, status corev1.ConditionStatus, reason string, message string) {
 	in.SetConditions(KameletCondition{
 		Type:               condType,
@@ -89,7 +89,7 @@ func (in *KameletStatus) SetCondition(condType KameletConditionType, status core
 	})
 }
 
-// SetErrorCondition --
+// SetErrorCondition --.
 func (in *KameletStatus) SetErrorCondition(condType KameletConditionType, reason string, err error) {
 	in.SetConditions(KameletCondition{
 		Type:               condType,
@@ -141,7 +141,7 @@ func (in *KameletStatus) RemoveCondition(condType KameletConditionType) {
 	in.Conditions = newConditions
 }
 
-// SortedDefinitionPropertiesKeys returns the sorted keys of the Kamelet definition properties
+// SortedDefinitionPropertiesKeys returns the sorted keys of the Kamelet definition properties.
 func (k *Kamelet) SortedDefinitionPropertiesKeys() []string {
 	if k.Spec.Definition == nil {
 		return []string{}
@@ -153,14 +153,14 @@ func (k *Kamelet) SortedDefinitionPropertiesKeys() []string {
 	res := make([]string, len(props))
 	i := 0
 	for key := range props {
-		res[i] = string(key)
+		res[i] = key
 		i++
 	}
 	sort.Strings(res)
 	return res
 }
 
-// SortedTypesKeys returns the sorted keys of the Kamelet spec types
+// SortedTypesKeys returns the sorted keys of the Kamelet spec types.
 func (k *Kamelet) SortedTypesKeys() []TypeSlot {
 	types := k.Spec.DataTypes
 	if len(types) == 0 {
@@ -194,7 +194,7 @@ func ValidKameletProperties(kamelet *Kamelet) bool {
 	return true
 }
 
-// NewKamelet creates a new kamelet
+// NewKamelet creates a new Kamelet.
 func NewKamelet(namespace string, name string) Kamelet {
 	return Kamelet{
 		TypeMeta: metav1.TypeMeta{
@@ -208,7 +208,7 @@ func NewKamelet(namespace string, name string) Kamelet {
 	}
 }
 
-// NewKameletList creates a new list of kamelets
+// NewKameletList creates a new list of Kamelets.
 func NewKameletList() KameletList {
 	return KameletList{
 		TypeMeta: metav1.TypeMeta{
