@@ -30,8 +30,6 @@ import (
 	platformutil "github.com/apache/camel-k/v2/pkg/platform"
 
 	"github.com/spf13/cobra"
-	"github.com/spf13/viper"
-
 	"go.uber.org/multierr"
 
 	corev1 "k8s.io/api/core/v1"
@@ -43,7 +41,6 @@ import (
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/v2/pkg/builder"
 	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/install"
 	"github.com/apache/camel-k/v2/pkg/util"
@@ -162,53 +159,52 @@ func newCmdInstall(rootCmdOptions *RootCmdOptions) (*cobra.Command, *installCmdO
 
 type installCmdOptions struct {
 	*RootCmdOptions
-	Wait                        bool `mapstructure:"wait"`
-	ClusterSetupOnly            bool `mapstructure:"cluster-setup"`
-	SkipOperatorSetup           bool `mapstructure:"skip-operator-setup"`
-	SkipClusterSetup            bool `mapstructure:"skip-cluster-setup"`
-	SkipRegistrySetup           bool `mapstructure:"skip-registry-setup"`
-	SkipDefaultKameletsSetup    bool `mapstructure:"skip-default-kamelets-setup"`
-	ExampleSetup                bool `mapstructure:"example"`
-	Global                      bool `mapstructure:"global"`
-	Save                        bool `mapstructure:"save" kamel:"omitsave"`
-	Force                       bool `mapstructure:"force"`
-	Olm                         bool `mapstructure:"olm"`
-	olmOptions                  olm.Options
-	ClusterType                 string   `mapstructure:"cluster-type"`
-	OutputFormat                string   `mapstructure:"output"`
-	RuntimeVersion              string   `mapstructure:"runtime-version"`
-	BaseImage                   string   `mapstructure:"base-image"`
-	OperatorID                  string   `mapstructure:"operator-id"`
-	OperatorImage               string   `mapstructure:"operator-image"`
-	OperatorImagePullPolicy     string   `mapstructure:"operator-image-pull-policy"`
-	BuildStrategy               string   `mapstructure:"build-strategy"`
-	BuildOrderStrategy          string   `mapstructure:"build-order-strategy"`
-	BuildPublishStrategy        string   `mapstructure:"build-publish-strategy"`
-	BuildPublishStrategyOptions []string `mapstructure:"build-publish-strategy-options"`
-	BuildTimeout                string   `mapstructure:"build-timeout"`
-	MavenExtensions             []string `mapstructure:"maven-extensions"`
-	MavenLocalRepository        string   `mapstructure:"maven-local-repository"`
-	MavenProperties             []string `mapstructure:"maven-properties"`
-	MavenRepositories           []string `mapstructure:"maven-repositories"`
-	MavenSettings               string   `mapstructure:"maven-settings"`
-	MavenCASecret               string   `mapstructure:"maven-ca-secret"`
-	MavenCLIOptions             []string `mapstructure:"maven-cli-options"`
-	HealthPort                  int32    `mapstructure:"health-port"`
-	MaxRunningBuilds            int32    `mapstructure:"max-running-pipelines"`
-	Monitoring                  bool     `mapstructure:"monitoring"`
-	MonitoringPort              int32    `mapstructure:"monitoring-port"`
-	Debugging                   bool     `mapstructure:"debugging"`
-	DebuggingPort               int32    `mapstructure:"debugging-port"`
-	DebuggingPath               string   `mapstructure:"debugging-path"`
-	TraitProfile                string   `mapstructure:"trait-profile"`
-	Tolerations                 []string `mapstructure:"tolerations"`
-	NodeSelectors               []string `mapstructure:"node-selectors"`
-	ResourcesRequirements       []string `mapstructure:"operator-resources"`
-	LogLevel                    string   `mapstructure:"log-level"`
-	EnvVars                     []string `mapstructure:"operator-env-vars"`
-	registry                    v1.RegistrySpec
-	registryAuth                registry.Auth
-	RegistryAuthFile            string `mapstructure:"registry-auth-file"`
+	Wait                     bool `mapstructure:"wait"`
+	ClusterSetupOnly         bool `mapstructure:"cluster-setup"`
+	SkipOperatorSetup        bool `mapstructure:"skip-operator-setup"`
+	SkipClusterSetup         bool `mapstructure:"skip-cluster-setup"`
+	SkipRegistrySetup        bool `mapstructure:"skip-registry-setup"`
+	SkipDefaultKameletsSetup bool `mapstructure:"skip-default-kamelets-setup"`
+	ExampleSetup             bool `mapstructure:"example"`
+	Global                   bool `mapstructure:"global"`
+	Save                     bool `mapstructure:"save" kamel:"omitsave"`
+	Force                    bool `mapstructure:"force"`
+	Olm                      bool `mapstructure:"olm"`
+	olmOptions               olm.Options
+	ClusterType              string   `mapstructure:"cluster-type"`
+	OutputFormat             string   `mapstructure:"output"`
+	RuntimeVersion           string   `mapstructure:"runtime-version"`
+	BaseImage                string   `mapstructure:"base-image"`
+	OperatorID               string   `mapstructure:"operator-id"`
+	OperatorImage            string   `mapstructure:"operator-image"`
+	OperatorImagePullPolicy  string   `mapstructure:"operator-image-pull-policy"`
+	BuildStrategy            string   `mapstructure:"build-strategy"`
+	BuildOrderStrategy       string   `mapstructure:"build-order-strategy"`
+	BuildPublishStrategy     string   `mapstructure:"build-publish-strategy"`
+	BuildTimeout             string   `mapstructure:"build-timeout"`
+	MavenExtensions          []string `mapstructure:"maven-extensions"`
+	MavenLocalRepository     string   `mapstructure:"maven-local-repository"`
+	MavenProperties          []string `mapstructure:"maven-properties"`
+	MavenRepositories        []string `mapstructure:"maven-repositories"`
+	MavenSettings            string   `mapstructure:"maven-settings"`
+	MavenCASecret            string   `mapstructure:"maven-ca-secret"`
+	MavenCLIOptions          []string `mapstructure:"maven-cli-options"`
+	HealthPort               int32    `mapstructure:"health-port"`
+	MaxRunningBuilds         int32    `mapstructure:"max-running-pipelines"`
+	Monitoring               bool     `mapstructure:"monitoring"`
+	MonitoringPort           int32    `mapstructure:"monitoring-port"`
+	Debugging                bool     `mapstructure:"debugging"`
+	DebuggingPort            int32    `mapstructure:"debugging-port"`
+	DebuggingPath            string   `mapstructure:"debugging-path"`
+	TraitProfile             string   `mapstructure:"trait-profile"`
+	Tolerations              []string `mapstructure:"tolerations"`
+	NodeSelectors            []string `mapstructure:"node-selectors"`
+	ResourcesRequirements    []string `mapstructure:"operator-resources"`
+	LogLevel                 string   `mapstructure:"log-level"`
+	EnvVars                  []string `mapstructure:"operator-env-vars"`
+	registry                 v1.RegistrySpec
+	registryAuth             registry.Auth
+	RegistryAuthFile         string `mapstructure:"registry-auth-file"`
 }
 
 func (o *installCmdOptions) install(cmd *cobra.Command, _ []string) error {
@@ -279,7 +275,7 @@ func (o *installCmdOptions) tryInstallViaOLM(
 	if err != nil {
 		return false, err
 	}
-	if olmAvailable, err := olm.IsAPIAvailable(o.Context, olmClient, o.Namespace); err != nil {
+	if olmAvailable, err := olm.IsAPIAvailable(olmClient); err != nil {
 		return false, fmt.Errorf("error while checking OLM availability. Run with '--olm=false' to skip this check: %w", err)
 
 	} else if !olmAvailable {
@@ -315,7 +311,14 @@ func (o *installCmdOptions) tryInstallViaOLM(
 }
 
 func (o *installCmdOptions) installOperator(cmd *cobra.Command, output *kubernetes.Collection, olm bool) error {
-	operatorID, err := getOperatorID(o.EnvVars)
+	var operatorID string
+	var err error
+	if o.OperatorID != "" {
+		operatorID = o.OperatorID
+	} else {
+		operatorID, err = getOperatorID(o.EnvVars)
+	}
+
 	if err != nil {
 		return err
 	}
@@ -568,7 +571,8 @@ func (o *installCmdOptions) setupIntegrationPlatform(c client.Client, namespace
 	}
 
 	if o.MavenSettings != "" {
-		mavenSettings, err := decodeMavenSettings(o.MavenSettings)
+		mavenSettings, err := v1.DecodeValueSource(o.MavenSettings, "settings.xml",
+			"illegal maven setting definition, syntax: configmap|secret:resource-name[/settings path]")
 		if err != nil {
 			return nil, err
 		}
@@ -590,11 +594,6 @@ func (o *installCmdOptions) setupIntegrationPlatform(c client.Client, namespace
 			}
 		}
 	}
-	if len(o.BuildPublishStrategyOptions) > 0 {
-		if err = o.addBuildPublishStrategyOptions(&platform.Spec.Build); err != nil {
-			return nil, err
-		}
-	}
 	// Always create a platform in the namespace where the operator is located
 	err = install.ObjectOrCollect(o.Context, c, namespace, output, o.Force, platform)
 	if err != nil {
@@ -675,25 +674,26 @@ func (o *installCmdOptions) postRun(cmd *cobra.Command, _ []string) error {
 
 func (o *installCmdOptions) decode(cmd *cobra.Command, _ []string) error {
 	path := pathToRoot(cmd)
-	if err := decodeKey(o, path); err != nil {
+
+	if err := decodeKey(o, path, o.Flags.AllSettings()); err != nil {
 		return err
 	}
 
-	o.registry.Address = viper.GetString(path + ".registry")
-	o.registry.Organization = viper.GetString(path + ".organization")
-	o.registry.Secret = viper.GetString(path + ".registry-secret")
-	o.registry.Insecure = viper.GetBool(path + ".registry-insecure")
-	o.registryAuth.Username = viper.GetString(path + ".registry-auth-username")
-	o.registryAuth.Password = viper.GetString(path + ".registry-auth-password")
-	o.registryAuth.Server = viper.GetString(path + ".registry-auth-server")
+	o.registry.Address = o.Flags.GetString(path + ".registry")
+	o.registry.Organization = o.Flags.GetString(path + ".organization")
+	o.registry.Secret = o.Flags.GetString(path + ".registry-secret")
+	o.registry.Insecure = o.Flags.GetBool(path + ".registry-insecure")
+	o.registryAuth.Username = o.Flags.GetString(path + ".registry-auth-username")
+	o.registryAuth.Password = o.Flags.GetString(path + ".registry-auth-password")
+	o.registryAuth.Server = o.Flags.GetString(path + ".registry-auth-server")
 
-	o.olmOptions.OperatorName = viper.GetString(path + ".olm-operator-name")
-	o.olmOptions.Package = viper.GetString(path + ".olm-package")
-	o.olmOptions.Channel = viper.GetString(path + ".olm-channel")
-	o.olmOptions.Source = viper.GetString(path + ".olm-source")
-	o.olmOptions.SourceNamespace = viper.GetString(path + ".olm-source-namespace")
-	o.olmOptions.StartingCSV = viper.GetString(path + ".olm-starting-csv")
-	o.olmOptions.GlobalNamespace = viper.GetString(path + ".olm-global-namespace")
+	o.olmOptions.OperatorName = o.Flags.GetString(path + ".olm-operator-name")
+	o.olmOptions.Package = o.Flags.GetString(path + ".olm-package")
+	o.olmOptions.Channel = o.Flags.GetString(path + ".olm-channel")
+	o.olmOptions.Source = o.Flags.GetString(path + ".olm-source")
+	o.olmOptions.SourceNamespace = o.Flags.GetString(path + ".olm-source-namespace")
+	o.olmOptions.StartingCSV = o.Flags.GetString(path + ".olm-starting-csv")
+	o.olmOptions.GlobalNamespace = o.Flags.GetString(path + ".olm-global-namespace")
 
 	return nil
 }
@@ -791,80 +791,6 @@ func (o *installCmdOptions) validate(_ *cobra.Command, _ []string) error {
 	return result
 }
 
-// addBuildPublishStrategyOptions parses and adds all the build publish strategy options to the given IntegrationPlatformBuildSpec.
-func (o *installCmdOptions) addBuildPublishStrategyOptions(pipeline *v1.IntegrationPlatformBuildSpec) error {
-	for _, option := range o.BuildPublishStrategyOptions {
-		kv := strings.Split(option, "=")
-		if len(kv) == 2 {
-			key := kv[0]
-			if builder.IsSupportedPublishStrategyOption(pipeline.PublishStrategy, key) {
-				pipeline.AddOption(key, kv[1])
-			} else {
-				return fmt.Errorf("build publish strategy option '%s' not supported. %s", option, supportedOptionsAsString(pipeline.PublishStrategy))
-			}
-		} else {
-			return fmt.Errorf("build publish strategy option '%s' not in the expected format (name=value)", option)
-		}
-	}
-	return nil
-}
-
-// supportedOptionsAsString provides all the supported options for the given strategy as string.
-func supportedOptionsAsString(strategy v1.IntegrationPlatformBuildPublishStrategy) string {
-	options := builder.GetSupportedPublishStrategyOptions(strategy)
-	if len(options) == 0 {
-		return fmt.Sprintf("no options are supported for the strategy '%s'.", strategy)
-	}
-	var sb strings.Builder
-	for _, supportedOption := range builder.GetSupportedPublishStrategyOptions(strategy) {
-		sb.WriteString(fmt.Sprintf("* %s\n", supportedOption.ToString()))
-	}
-	return fmt.Sprintf("\n\nSupported options for the strategy '%s':\n\n%s", strategy, sb.String())
-}
-
-func decodeMavenSettings(mavenSettings string) (v1.ValueSource, error) {
-	sub := make([]string, 0)
-	rex := regexp.MustCompile(`^(configmap|secret):([a-zA-Z0-9][a-zA-Z0-9-]*)(/([a-zA-Z0-9].*))?$`)
-	hits := rex.FindAllStringSubmatch(mavenSettings, -1)
-
-	for _, hit := range hits {
-		if len(hit) > 1 {
-			sub = append(sub, hit[1:]...)
-		}
-	}
-
-	if len(sub) >= 2 {
-		key := "settings.xml"
-
-		if len(sub) == 4 {
-			key = sub[3]
-		}
-
-		if sub[0] == "configmap" {
-			return v1.ValueSource{
-				ConfigMapKeyRef: &corev1.ConfigMapKeySelector{
-					LocalObjectReference: corev1.LocalObjectReference{
-						Name: sub[1],
-					},
-					Key: key,
-				},
-			}, nil
-		}
-		if sub[0] == "secret" {
-			return v1.ValueSource{
-				SecretKeyRef: &corev1.SecretKeySelector{
-					LocalObjectReference: corev1.LocalObjectReference{
-						Name: sub[1],
-					},
-					Key: key,
-				},
-			}, nil
-		}
-	}
-
-	return v1.ValueSource{}, fmt.Errorf("illegal maven setting definition, syntax: configmap|secret:resource-name[/settings path]")
-}
-
 func decodeSecretKeySelector(secretKey string) (*corev1.SecretKeySelector, error) {
 	r := regexp.MustCompile(`^([a-zA-Z0-9-]*)/([a-zA-Z0-9].*)$`)
 
