@@ -30,17 +30,22 @@ import (
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/selection"
+	"k8s.io/utils/pointer"
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
 	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/trait"
 	"github.com/apache/camel-k/v2/pkg/util/digest"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	utilResource "github.com/apache/camel-k/v2/pkg/util/resource"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
+// NewMonitorAction is an action used to monitor manager Integrations.
 func NewMonitorAction() Action {
 	return &monitorAction{}
 }
@@ -64,10 +69,10 @@ func (action *monitorAction) Handle(ctx context.Context, integration *v1.Integra
 	// so handle it differently from the rest
 	if isInInitializationFailed(integration.Status) {
 		// Only check if the Integration requires a rebuild
-		return action.checkDigestAndRebuild(integration, nil)
+		return action.checkDigestAndRebuild(ctx, integration, nil)
 	}
 
-	// At that staged the Integration must have a Kit
+	// At this stage the Integration must have a Kit
 	if integration.Status.IntegrationKit == nil {
 		return nil, fmt.Errorf("no kit set on integration %s", integration.Name)
 	}
@@ -79,8 +84,14 @@ func (action *monitorAction) Handle(ctx context.Context, integration *v1.Integra
 			integration.Status.IntegrationKit.Namespace, integration.Status.IntegrationKit.Name, err)
 	}
 
+	// If integration is in error and its kit is also in error then integration does not change
+	if isInIntegrationKitFailed(integration.Status) &&
+		kit.Status.Phase == v1.IntegrationKitPhaseError {
+		return nil, nil
+	}
+
 	// Check if the Integration requires a rebuild
-	if changed, err := action.checkDigestAndRebuild(integration, kit); err != nil {
+	if changed, err := action.checkDigestAndRebuild(ctx, integration, kit); err != nil {
 		return nil, err
 	} else if changed != nil {
 		return changed, nil
@@ -96,6 +107,7 @@ func (action *monitorAction) Handle(ctx context.Context, integration *v1.Integra
 	if err != nil {
 		return nil, err
 	}
+
 	kits, err := lookupKitsForIntegration(ctx, action.client, integration, ctrl.MatchingLabelsSelector{
 		Selector: labels.NewSelector().Add(*withHigherPriority),
 	})
@@ -112,10 +124,44 @@ func (action *monitorAction) Handle(ctx context.Context, integration *v1.Integra
 
 	// Run traits that are enabled for the phase
 	environment, err := trait.Apply(ctx, action.client, integration, kit)
+	if err != nil {
+		integration.Status.Phase = v1.IntegrationPhaseError
+		integration.SetReadyCondition(corev1.ConditionFalse,
+			v1.IntegrationConditionInitializationFailedReason, err.Error())
+		return integration, err
+	}
+
+	return action.monitorPods(ctx, environment, integration)
+}
+
+func (action *monitorAction) monitorPods(ctx context.Context, environment *trait.Environment, integration *v1.Integration) (*v1.Integration, error) {
+	controller, err := action.newController(environment, integration)
 	if err != nil {
 		return nil, err
 	}
 
+	// In order to simplify the monitoring and have a minor resource requirement, we will watch only those Pods
+	// which are labeled with `camel.apache.org/integration`. This is a design choice that requires the user to
+	// voluntarily add a label to their Pods (via template, possibly) in order to monitor the non managed Camel applications.
+
+	if !controller.hasTemplateIntegrationLabel() {
+		// This is happening when the Deployment, CronJob, etc resources
+		// miss the Integration label, required to identify sibling Pods.
+		integration.Status.SetConditions(
+			v1.IntegrationCondition{
+				Type:   v1.IntegrationConditionReady,
+				Status: corev1.ConditionFalse,
+				Reason: v1.IntegrationConditionMonitoringPodsAvailableReason,
+				Message: fmt.Sprintf(
+					"Could not find `camel.apache.org/integration: %s` label in the %s template. Make sure to include this label in the template for Pod monitoring purposes.",
+					integration.GetName(),
+					controller.getControllerName(),
+				),
+			},
+		)
+		return integration, nil
+	}
+
 	// Enforce the scale sub-resource label selector.
 	// It is used by the HPA that queries the scale sub-resource endpoint,
 	// to list the pods owned by the integration.
@@ -153,7 +199,7 @@ func (action *monitorAction) Handle(ctx context.Context, integration *v1.Integra
 		integration.Status.Phase = v1.IntegrationPhaseRunning
 	}
 	if err = action.updateIntegrationPhaseAndReadyCondition(
-		ctx, environment, integration, pendingPods.Items, runningPods.Items,
+		ctx, controller, environment, integration, pendingPods.Items, runningPods.Items,
 	); err != nil {
 		return nil, err
 	}
@@ -175,25 +221,29 @@ func isInInitializationFailed(status v1.IntegrationStatus) bool {
 	return false
 }
 
-func (action *monitorAction) checkDigestAndRebuild(
-	integration *v1.Integration, kit *v1.IntegrationKit,
-) (*v1.Integration, error) {
-	hash, err := digest.ComputeForIntegration(integration)
+func isInIntegrationKitFailed(status v1.IntegrationStatus) bool {
+	if cond := status.GetCondition(v1.IntegrationConditionKitAvailable); cond != nil {
+		if cond.Status == corev1.ConditionFalse &&
+			status.Phase != v1.IntegrationPhaseError {
+			return true
+		}
+	}
+
+	return false
+}
+
+func (action *monitorAction) checkDigestAndRebuild(ctx context.Context, integration *v1.Integration, kit *v1.IntegrationKit) (*v1.Integration, error) {
+	secrets, configmaps := getIntegrationSecretAndConfigmapResourceVersions(ctx, action.client, integration)
+	hash, err := digest.ComputeForIntegration(integration, configmaps, secrets)
 	if err != nil {
 		return nil, err
 	}
 
 	if hash != integration.Status.Digest {
-		action.L.Info("Monitor: Integration needs a rebuild")
-
-		if kit != nil &&
-			v1.GetOperatorIDAnnotation(integration) != "" &&
-			v1.GetOperatorIDAnnotation(integration) != v1.GetOperatorIDAnnotation(kit) {
-			// Operator to reconcile the integration has changed. Reset integration kit
-			// so new operator can handle the kit reference
+		action.L.Infof("Integration %s digest has changed: resetting its status. Will check if it needs to be rebuilt and restarted.", integration.Name)
+		if isIntegrationKitResetRequired(integration, kit) {
 			integration.SetIntegrationKit(nil)
 		}
-
 		integration.Initialize()
 		integration.Status.Digest = hash
 
@@ -203,10 +253,82 @@ func (action *monitorAction) checkDigestAndRebuild(
 	return nil, nil
 }
 
+func isIntegrationKitResetRequired(integration *v1.Integration, kit *v1.IntegrationKit) bool {
+	if kit == nil {
+		return false
+	}
+
+	if v1.GetOperatorIDAnnotation(integration) != "" &&
+		v1.GetOperatorIDAnnotation(integration) != v1.GetOperatorIDAnnotation(kit) {
+		// Operator to reconcile the integration has changed. Reset integration kit
+		// so new operator can handle the kit reference
+		return true
+	}
+
+	if v1.GetIntegrationProfileAnnotation(integration) != "" &&
+		v1.GetIntegrationProfileAnnotation(integration) != v1.GetIntegrationProfileAnnotation(kit) {
+		// Integration profile for the integration has changed. Reset integration kit
+		// so new profile can be applied
+		return true
+	}
+
+	if v1.GetIntegrationProfileNamespaceAnnotation(integration) != "" &&
+		v1.GetIntegrationProfileNamespaceAnnotation(integration) != v1.GetIntegrationProfileNamespaceAnnotation(kit) {
+		// Integration profile namespace for the integration has changed. Reset integration kit
+		// so new profile can be applied
+		return true
+	}
+
+	return false
+}
+
+// getIntegrationSecretAndConfigmapResourceVersions returns the list of resource versions only useful to watch for changes.
+func getIntegrationSecretAndConfigmapResourceVersions(ctx context.Context, client client.Client, integration *v1.Integration) ([]string, []string) {
+	configmaps := make([]string, 0)
+	secrets := make([]string, 0)
+	if integration.Spec.Traits.Mount != nil && pointer.BoolDeref(integration.Spec.Traits.Mount.HotReload, false) {
+		mergedResources := make([]string, 0)
+		mergedResources = append(mergedResources, integration.Spec.Traits.Mount.Configs...)
+		mergedResources = append(mergedResources, integration.Spec.Traits.Mount.Resources...)
+		for _, c := range mergedResources {
+			if conf, parseErr := utilResource.ParseConfig(c); parseErr == nil {
+				if conf.StorageType() == utilResource.StorageTypeConfigmap {
+					cm := corev1.ConfigMap{
+						TypeMeta: metav1.TypeMeta{
+							Kind:       "ConfigMap",
+							APIVersion: corev1.SchemeGroupVersion.String(),
+						},
+						ObjectMeta: metav1.ObjectMeta{
+							Namespace: integration.Namespace,
+							Name:      conf.Name(),
+						},
+					}
+					configmaps = append(configmaps, kubernetes.LookupResourceVersion(ctx, client, &cm))
+				} else if conf.StorageType() == utilResource.StorageTypeSecret {
+					sec := corev1.Secret{
+						TypeMeta: metav1.TypeMeta{
+							Kind:       "Secret",
+							APIVersion: corev1.SchemeGroupVersion.String(),
+						},
+						ObjectMeta: metav1.ObjectMeta{
+							Namespace: integration.Namespace,
+							Name:      conf.Name(),
+						},
+					}
+					secrets = append(secrets, kubernetes.LookupResourceVersion(ctx, client, &sec))
+				}
+			}
+		}
+	}
+	return secrets, configmaps
+}
+
 type controller interface {
 	checkReadyCondition(ctx context.Context) (bool, error)
 	getPodSpec() corev1.PodSpec
-	updateReadyCondition(readyPods []corev1.Pod) bool
+	updateReadyCondition(readyPods int) bool
+	hasTemplateIntegrationLabel() bool
+	getControllerName() string
 }
 
 func (action *monitorAction) newController(env *trait.Environment, integration *v1.Integration) (controller, error) {
@@ -217,7 +339,7 @@ func (action *monitorAction) newController(env *trait.Environment, integration *
 		obj = getUpdatedController(env, &appsv1.Deployment{})
 		deploy, ok := obj.(*appsv1.Deployment)
 		if !ok {
-			return nil, fmt.Errorf("type assertion failed: %v", obj)
+			return nil, fmt.Errorf("type assertion failed, not a Deployment: %v", obj)
 		}
 		controller = &deploymentController{
 			obj:         deploy,
@@ -227,7 +349,7 @@ func (action *monitorAction) newController(env *trait.Environment, integration *
 		obj = getUpdatedController(env, &servingv1.Service{})
 		svc, ok := obj.(*servingv1.Service)
 		if !ok {
-			return nil, fmt.Errorf("type assertion failed: %v", obj)
+			return nil, fmt.Errorf("type assertion failed, not a Knative Service: %v", obj)
 		}
 		controller = &knativeServiceController{
 			obj:         svc,
@@ -237,7 +359,7 @@ func (action *monitorAction) newController(env *trait.Environment, integration *
 		obj = getUpdatedController(env, &batchv1.CronJob{})
 		cj, ok := obj.(*batchv1.CronJob)
 		if !ok {
-			return nil, fmt.Errorf("type assertion failed: %v", obj)
+			return nil, fmt.Errorf("type assertion failed, not a CronJob: %v", obj)
 		}
 		controller = &cronJobController{
 			obj:         cj,
@@ -263,38 +385,35 @@ func getUpdatedController(env *trait.Environment, obj ctrl.Object) ctrl.Object {
 }
 
 func (action *monitorAction) updateIntegrationPhaseAndReadyCondition(
-	ctx context.Context, environment *trait.Environment, integration *v1.Integration,
+	ctx context.Context, controller controller, environment *trait.Environment, integration *v1.Integration,
 	pendingPods []corev1.Pod, runningPods []corev1.Pod,
 ) error {
-	controller, err := action.newController(environment, integration)
-	if err != nil {
-		return err
-	}
-
-	readyPods, unreadyPods := filterPodsByReadyStatus(environment, runningPods, controller.getPodSpec())
-
 	if done, err := controller.checkReadyCondition(ctx); done || err != nil {
 		// There may be pods that are not ready but still probable for getting error messages.
 		// Ignore returned error from probing as it's expected when the ctrl obj is not ready.
-		_ = action.probeReadiness(ctx, environment, integration, unreadyPods, readyPods)
+		_, _, _ = action.probeReadiness(ctx, environment, integration, runningPods)
 		return err
 	}
-	if done := checkPodStatuses(integration, pendingPods, runningPods); done {
+	if arePodsFailingStatuses(integration, pendingPods, runningPods) {
+		return nil
+	}
+	readyPods, probeOk, err := action.probeReadiness(ctx, environment, integration, runningPods)
+	if err != nil {
+		return err
+	}
+	if !probeOk {
+		integration.Status.Phase = v1.IntegrationPhaseError
 		return nil
 	}
-	integration.Status.Phase = v1.IntegrationPhaseRunning
-
 	if done := controller.updateReadyCondition(readyPods); done {
+		integration.Status.Phase = v1.IntegrationPhaseRunning
 		return nil
 	}
-	if err := action.probeReadiness(ctx, environment, integration, unreadyPods, readyPods); err != nil {
-		return err
-	}
 
 	return nil
 }
 
-func checkPodStatuses(integration *v1.Integration, pendingPods []corev1.Pod, runningPods []corev1.Pod) bool {
+func arePodsFailingStatuses(integration *v1.Integration, pendingPods []corev1.Pod, runningPods []corev1.Pod) bool {
 	// Check Pods statuses
 	for _, pod := range pendingPods {
 		// Check the scheduled condition
@@ -346,114 +465,44 @@ func checkPodStatuses(integration *v1.Integration, pendingPods []corev1.Pod, run
 	return false
 }
 
-func filterPodsByReadyStatus(environment *trait.Environment, runningPods []corev1.Pod, podSpec corev1.PodSpec) ([]corev1.Pod, []corev1.Pod) {
-	var readyPods []corev1.Pod
-	var unreadyPods []corev1.Pod
-
-	integrationContainerName := environment.GetIntegrationContainerName()
-	for _, pod := range runningPods {
-		// We compare the Integration PodSpec to that of the Pod in order to make
-		// sure we account for up-to-date version.
-		if !comparePodSpec(integrationContainerName, podSpec, pod.Spec) {
-			continue
-		}
-		ready := kubernetes.GetPodCondition(pod, corev1.PodReady)
-		if ready == nil {
-			continue
-		}
-		switch ready.Status {
-		case corev1.ConditionTrue:
-			// We still account terminating Pods to handle rolling deployments
-			readyPods = append(readyPods, pod)
-		case corev1.ConditionFalse:
-			if pod.DeletionTimestamp != nil {
-				continue
-			}
-			unreadyPods = append(unreadyPods, pod)
-		}
-	}
-
-	return readyPods, unreadyPods
-}
-
-// comparePodSpec compares given pod spec according to integration specific information (e.g. digest, container image).
-func comparePodSpec(integrationContainerName string, runningPodSpec corev1.PodSpec, referencePod corev1.PodSpec) bool {
-	runningPodContainer := findIntegrationContainer(integrationContainerName, runningPodSpec)
-	referencePodContainer := findIntegrationContainer(integrationContainerName, referencePod)
-
-	if runningPodContainer == nil || referencePodContainer == nil {
-		return false
-	}
-
-	// integration digest must be the same
-	if getIntegrationDigest(runningPodContainer.Env) != getIntegrationDigest(referencePodContainer.Env) {
-		return false
-	}
-
-	// integration container image must be the same (same integration kit)
-	if runningPodContainer.Image != referencePodContainer.Image {
-		return false
-	}
-
-	return true
-}
-
-func getIntegrationDigest(envs []corev1.EnvVar) string {
-	for _, env := range envs {
-		if env.Name == digest.IntegrationDigestEnvVar {
-			return env.Value
-		}
-	}
-
-	return ""
-}
-
-// findIntegrationContainer find if present the integration container in the pod spec using the integration specifications.
-func findIntegrationContainer(integrationContainerName string, spec corev1.PodSpec) *corev1.Container {
-	for _, c := range spec.Containers {
-		if c.Name == integrationContainerName {
-			return &c
-		}
-	}
-
-	return nil
-}
-
 // probeReadiness calls the readiness probes of the non-ready Pods directly to retrieve insights from the Camel runtime.
-func (action *monitorAction) probeReadiness(
-	ctx context.Context, environment *trait.Environment, integration *v1.Integration,
-	unreadyPods []corev1.Pod, readyPods []corev1.Pod,
-) error {
+// The func return the number of readyPods, the success of the probe and any error may have happened during its execution.
+func (action *monitorAction) probeReadiness(ctx context.Context, environment *trait.Environment, integration *v1.Integration, pods []corev1.Pod) (int, bool, error) {
+	// as a default we assume the Integration is Ready
 	readyCondition := v1.IntegrationCondition{
 		Type:   v1.IntegrationConditionReady,
-		Status: corev1.ConditionFalse,
-		Pods:   make([]v1.PodCondition, len(unreadyPods)),
+		Status: corev1.ConditionTrue,
+		Pods:   make([]v1.PodCondition, len(pods)),
 	}
 
+	readyPods := 0
+	unreadyPods := 0
+
 	runtimeReady := true
 	runtimeFailed := false
+	probeReadinessOk := true
 
-	for i := range unreadyPods {
-		pod := &unreadyPods[i]
-		if ready := kubernetes.GetPodCondition(*pod, corev1.PodReady); ready.Reason != "ContainersNotReady" {
-			continue
-		}
-		container := getIntegrationContainer(environment, pod)
-		if container == nil {
-			return fmt.Errorf("integration container not found in Pod %s/%s", pod.Namespace, pod.Name)
-		}
-
+	for i := range pods {
+		pod := &pods[i]
 		readyCondition.Pods[i].Name = pod.Name
-
 		for p := range pod.Status.Conditions {
 			if pod.Status.Conditions[p].Type == corev1.PodReady {
 				readyCondition.Pods[i].Condition = pod.Status.Conditions[p]
 				break
 			}
 		}
+		// If it's in ready status, then we don't care to probe.
+		if ready := kubernetes.GetPodCondition(*pod, corev1.PodReady); ready.Status == corev1.ConditionTrue {
+			readyPods++
+			continue
+		}
+		unreadyPods++
+		container := getIntegrationContainer(environment, pod)
+		if container == nil {
+			return readyPods, false, fmt.Errorf("integration container not found in Pod %s/%s", pod.Namespace, pod.Name)
+		}
 		if probe := container.ReadinessProbe; probe != nil && probe.HTTPGet != nil {
 			body, err := proxyGetHTTPProbe(ctx, action.client, probe, pod, container)
-
 			// When invoking the HTTP probe, the kubernetes client exposes a very
 			// specific behavior:
 			//
@@ -509,7 +558,7 @@ func (action *monitorAction) probeReadiness(
 
 			health, err := NewHealthCheck(body)
 			if err != nil {
-				return err
+				return readyPods, false, err
 			}
 			for _, check := range health.Checks {
 				if check.Status == v1.HealthCheckStatusUp {
@@ -525,19 +574,21 @@ func (action *monitorAction) probeReadiness(
 	}
 
 	if runtimeFailed {
-		integration.Status.Phase = v1.IntegrationPhaseError
+		probeReadinessOk = false
 		readyCondition.Reason = v1.IntegrationConditionErrorReason
-		readyCondition.Message = fmt.Sprintf("%d/%d pods are not ready", len(unreadyPods), len(unreadyPods)+len(readyPods))
+		readyCondition.Status = corev1.ConditionFalse
+		readyCondition.Message = fmt.Sprintf("%d/%d pods are not ready", unreadyPods, unreadyPods+readyPods)
+		integration.Status.SetConditions(readyCondition)
 	}
 	if !runtimeReady {
-		integration.Status.Phase = v1.IntegrationPhaseError
+		probeReadinessOk = false
 		readyCondition.Reason = v1.IntegrationConditionRuntimeNotReadyReason
-		readyCondition.Message = fmt.Sprintf("%d/%d pods are not ready", len(unreadyPods), len(unreadyPods)+len(readyPods))
+		readyCondition.Status = corev1.ConditionFalse
+		readyCondition.Message = fmt.Sprintf("%d/%d pods are not ready", unreadyPods, unreadyPods+readyPods)
+		integration.Status.SetConditions(readyCondition)
 	}
 
-	integration.Status.SetConditions(readyCondition)
-
-	return nil
+	return readyPods, probeReadinessOk, nil
 }
 
 func findHighestPriorityReadyKit(kits []v1.IntegrationKit) (*v1.IntegrationKit, error) {
