@@ -33,7 +33,6 @@ import (
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/v2/pkg/builder"
 	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/install"
 	"github.com/apache/camel-k/v2/pkg/kamelet/repository"
@@ -76,23 +75,13 @@ func ConfigureDefaults(ctx context.Context, c client.Client, p *v1.IntegrationPl
 		if p.Status.Cluster == v1.IntegrationPlatformClusterOpenShift {
 			p.Status.Build.PublishStrategy = v1.IntegrationPlatformBuildPublishStrategyS2I
 		} else {
-			p.Status.Build.PublishStrategy = v1.IntegrationPlatformBuildPublishStrategySpectrum
+			p.Status.Build.PublishStrategy = v1.IntegrationPlatformBuildPublishStrategyJib
 		}
 		log.Debugf("Integration Platform %s [%s]: setting publishing strategy %s", p.Name, p.Namespace, p.Status.Build.PublishStrategy)
 	}
 
 	if p.Status.Build.BuildConfiguration.Strategy == "" {
 		defaultStrategy := v1.BuildStrategyRoutine
-		if p.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyBuildah ||
-			p.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyKaniko {
-			defaultStrategy = v1.BuildStrategyPod
-			log.Infof("Integration Platform %s [%s]: setting fallback build strategy %s because PublishStrategy is configured as %s",
-				p.Name,
-				p.Namespace,
-				defaultStrategy,
-				p.Status.Build.PublishStrategy,
-			)
-		}
 		p.Status.Build.BuildConfiguration.Strategy = defaultStrategy
 		log.Debugf("Integration Platform %s [%s]: setting build strategy %s", p.Name, p.Namespace, p.Status.Build.BuildConfiguration.Strategy)
 	}
@@ -151,7 +140,7 @@ func configureRegistry(ctx context.Context, c client.Client, p *v1.IntegrationPl
 		p.Status.Build.Registry.Address == "" {
 		log.Debugf("Integration Platform %s [%s]: setting registry address", p.Name, p.Namespace)
 		// Default to using OpenShift internal container images registry when using a strategy other than S2I
-		p.Status.Build.Registry.Address = "image-registry.openshift-image-registry.svc:5000"
+		p.Status.Build.Registry.Address = defaults.OpenShiftRegistryAddress
 
 		// OpenShift automatically injects the service CA certificate into the service-ca.crt key on the ConfigMap
 		cm, err := createServiceCaBundleConfigMap(ctx, c, p)
@@ -201,22 +190,15 @@ func configureRegistry(ctx context.Context, c client.Client, p *v1.IntegrationPl
 
 func applyGlobalPlatformDefaults(ctx context.Context, c client.Client, p *v1.IntegrationPlatform) error {
 	operatorNamespace := GetOperatorNamespace()
-	if operatorNamespace != "" && operatorNamespace != p.Namespace {
+	if operatorNamespace != "" {
 		operatorID := defaults.OperatorID()
-		if operatorID != "" {
-			if globalPlatform, err := get(ctx, c, operatorNamespace, operatorID); err != nil && !k8serrors.IsNotFound(err) {
+		if operatorNamespace != p.Namespace || (operatorID != "" && p.Name != operatorID) {
+			if globalPlatform, err := findLocal(ctx, c, operatorNamespace); err != nil && !k8serrors.IsNotFound(err) {
 				return err
 			} else if globalPlatform != nil {
 				applyPlatformSpec(globalPlatform, p)
-				return nil
 			}
 		}
-
-		if globalPlatform, err := findLocal(ctx, c, operatorNamespace, true); err != nil && !k8serrors.IsNotFound(err) {
-			return err
-		} else if globalPlatform != nil {
-			applyPlatformSpec(globalPlatform, p)
-		}
 	}
 
 	return nil
@@ -253,10 +235,6 @@ func applyPlatformSpec(source *v1.IntegrationPlatform, target *v1.IntegrationPla
 	if target.Status.Build.BaseImage == "" {
 		log.Debugf("Integration Platform %s [%s]: setting base image", target.Name, target.Namespace)
 		target.Status.Build.BaseImage = source.Status.Build.BaseImage
-		// Workaround to ensure the default image from buildah is full name. Any baseImage override is in charge of it's validity
-		if target.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyBuildah && defaults.IsBaseImageDefault() {
-			target.Status.Build.BaseImage = builder.BuildahDefaultBaseImageName
-		}
 	}
 
 	if target.Status.Build.Maven.LocalRepository == "" {
@@ -307,12 +285,6 @@ func applyPlatformSpec(source *v1.IntegrationPlatform, target *v1.IntegrationPla
 		target.Status.Build.Timeout = source.Status.Build.Timeout
 	}
 
-	// Catalog tools build timeout
-	if target.Status.Build.BuildCatalogToolTimeout == nil {
-		log.Debugf("Integration Platform %s [%s]: setting build camel catalog tool timeout", target.Name, target.Namespace)
-		target.Status.Build.BuildCatalogToolTimeout = source.Status.Build.BuildCatalogToolTimeout
-	}
-
 	if target.Status.Build.MaxRunningBuilds <= 0 {
 		log.Debugf("Integration Platform %s [%s]: setting max running builds", target.Name, target.Namespace)
 		target.Status.Build.MaxRunningBuilds = source.Status.Build.MaxRunningBuilds
@@ -336,10 +308,6 @@ func setPlatformDefaults(p *v1.IntegrationPlatform, verbose bool) error {
 	if p.Status.Build.BaseImage == "" {
 		log.Debugf("Integration Platform %s [%s]: setting base image", p.Name, p.Namespace)
 		p.Status.Build.BaseImage = defaults.BaseImage()
-		// Workaround to ensure the default image from buildah is full name. Any baseImage override is in charge of it's validity
-		if p.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyBuildah && defaults.IsBaseImageDefault() {
-			p.Status.Build.BaseImage = builder.BuildahDefaultBaseImageName
-		}
 	}
 	if p.Status.Build.Maven.LocalRepository == "" {
 		log.Debugf("Integration Platform %s [%s]: setting local repository", p.Name, p.Namespace)
@@ -353,10 +321,6 @@ func setPlatformDefaults(p *v1.IntegrationPlatform, verbose bool) error {
 			"-Dstyle.color=never",
 		}
 	}
-	if _, ok := p.Status.Build.PublishStrategyOptions[builder.KanikoPVCName]; !ok {
-		log.Debugf("Integration Platform %s [%s]: setting publish strategy options", p.Name, p.Namespace)
-		p.Status.Build.PublishStrategyOptions[builder.KanikoPVCName] = p.Name
-	}
 
 	// Build timeout
 	if p.Status.Build.GetTimeout().Duration == 0 {
@@ -376,25 +340,6 @@ func setPlatformDefaults(p *v1.IntegrationPlatform, verbose bool) error {
 		}
 	}
 
-	// Catalog tools build timeout
-	if p.Status.Build.GetBuildCatalogToolTimeout().Duration == 0 {
-		log.Debugf("Integration Platform %s [%s]: setting default build camel catalog tool timeout (1 minute)", p.Name, p.Namespace)
-		p.Status.Build.BuildCatalogToolTimeout = &metav1.Duration{
-			Duration: 1 * time.Minute,
-		}
-	} else {
-		d := p.Status.Build.GetBuildCatalogToolTimeout().Duration.Truncate(time.Second)
-
-		if verbose && p.Status.Build.GetBuildCatalogToolTimeout().Duration != d {
-			log.Log.Infof("Build catalog tools timeout minimum unit is sec (configured: %s, truncated: %s)", p.Status.Build.GetBuildCatalogToolTimeout().Duration, d)
-		}
-
-		log.Debugf("Integration Platform %s [%s]: setting build catalog tools timeout", p.Name, p.Namespace)
-		p.Status.Build.BuildCatalogToolTimeout = &metav1.Duration{
-			Duration: d,
-		}
-	}
-
 	if p.Status.Build.MaxRunningBuilds <= 0 {
 		log.Debugf("Integration Platform %s [%s]: setting max running builds", p.Name, p.Namespace)
 		if p.Status.Build.BuildConfiguration.Strategy == v1.BuildStrategyRoutine {
@@ -404,21 +349,9 @@ func setPlatformDefaults(p *v1.IntegrationPlatform, verbose bool) error {
 		}
 	}
 
-	_, cacheEnabled := p.Status.Build.PublishStrategyOptions[builder.KanikoBuildCacheEnabled]
-	if p.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyKaniko && !cacheEnabled {
-		// Default to disabling Kaniko cache warmer
-		// Using the cache warmer pod seems unreliable with the current Kaniko version
-		// and requires relying on a persistent volume.
-		defaultKanikoBuildCache := "false"
-		p.Status.Build.PublishStrategyOptions[builder.KanikoBuildCacheEnabled] = defaultKanikoBuildCache
-		if verbose {
-			log.Log.Infof("Kaniko cache set to %s", defaultKanikoBuildCache)
-		}
-	}
-
 	if len(p.Status.Kamelet.Repositories) == 0 {
 		log.Debugf("Integration Platform %s [%s]: setting kamelet repositories", p.Name, p.Namespace)
-		p.Status.Kamelet.Repositories = append(p.Status.Kamelet.Repositories, v1.IntegrationPlatformKameletRepositorySpec{
+		p.Status.Kamelet.Repositories = append(p.Status.Kamelet.Repositories, v1.KameletRepositorySpec{
 			URI: repository.DefaultRemoteRepository,
 		})
 	}
@@ -436,13 +369,6 @@ func setPlatformDefaults(p *v1.IntegrationPlatform, verbose bool) error {
 
 func setStatusAdditionalInfo(platform *v1.IntegrationPlatform) {
 	platform.Status.Info = make(map[string]string)
-
-	log.Debugf("Integration Platform %s [%s]: setting build publish strategy", platform.Name, platform.Namespace)
-	if platform.Spec.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyBuildah {
-		platform.Status.Info["buildahVersion"] = defaults.BuildahVersion
-	} else if platform.Spec.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyKaniko {
-		platform.Status.Info["kanikoVersion"] = defaults.KanikoVersion
-	}
 	log.Debugf("Integration Platform %s [%s]: setting status info", platform.Name, platform.Namespace)
 	platform.Status.Info["goVersion"] = runtime.Version()
 	platform.Status.Info["goOS"] = runtime.GOOS
