@@ -43,9 +43,10 @@ func TestMountVolumesEmpty(t *testing.T) {
 	environment.Integration.Spec.Traits = v1.Traits{} // empty traits
 	environment.Platform.ResyncStatusFullConfig()
 
-	err := traitCatalog.apply(environment)
+	conditions, err := traitCatalog.apply(environment)
 
 	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("mount"))
 
@@ -65,9 +66,10 @@ func TestMountVolumesIntegrationPhaseDeploying(t *testing.T) {
 	environment := getNominalEnv(t, traitCatalog)
 	environment.Platform.ResyncStatusFullConfig()
 
-	err := traitCatalog.apply(environment)
+	conditions, err := traitCatalog.apply(environment)
 
 	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("mount"))
 
@@ -113,9 +115,10 @@ func TestMountVolumesIntegrationPhaseInitialization(t *testing.T) {
 	environment.Integration.Status.Phase = v1.IntegrationPhaseInitialization
 	environment.Platform.ResyncStatusFullConfig()
 
-	err := traitCatalog.apply(environment)
+	conditions, err := traitCatalog.apply(environment)
 
 	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.Nil(t, environment.GetTrait("mount"))
 
