@@ -27,24 +27,20 @@ import (
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestToTraitMap(t *testing.T) {
 	traits := v1.Traits{
 		Container: &traitv1.ContainerTrait{
-			Trait: traitv1.Trait{
-				Enabled: pointer.Bool(true),
-				Configuration: configurationFromMap(t, map[string]interface{}{
-					"name": "test-container",
-					"port": 8082,
-				}),
-			},
-			Auto:            pointer.Bool(false),
-			Expose:          pointer.Bool(true),
-			Port:            8081,
-			PortName:        "http-8081",
-			ServicePort:     81,
-			ServicePortName: "http-81",
+			PlatformBaseTrait: traitv1.PlatformBaseTrait{},
+			Name:              "test-container",
+			Auto:              pointer.Bool(false),
+			Expose:            pointer.Bool(true),
+			Port:              8081,
+			PortName:          "http-8081",
+			ServicePort:       81,
+			ServicePortName:   "http-81",
 		},
 		Service: &traitv1.ServiceTrait{
 			Trait: traitv1.Trait{
@@ -59,17 +55,13 @@ func TestToTraitMap(t *testing.T) {
 	}
 	expected := Options{
 		"container": {
-			"enabled":         true,
 			"auto":            false,
 			"expose":          true,
 			"port":            float64(8081),
 			"portName":        "http-8081",
 			"servicePort":     float64(81),
 			"servicePortName": "http-81",
-			"configuration": map[string]interface{}{
-				"name": "test-container",
-				"port": float64(8082),
-			},
+			"name":            "test-container",
 		},
 		"service": {
 			"enabled": true,
@@ -83,43 +75,34 @@ func TestToTraitMap(t *testing.T) {
 
 	traitMap, err := ToTraitMap(traits)
 
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, expected, traitMap)
 }
 
 func TestToPropertyMap(t *testing.T) {
 	trait := traitv1.ContainerTrait{
-		Trait: traitv1.Trait{
-			Enabled: pointer.Bool(true),
-			Configuration: configurationFromMap(t, map[string]interface{}{
-				"name": "test-container",
-				"port": 8082,
-			}),
-		},
-		Auto:            pointer.Bool(false),
-		Expose:          pointer.Bool(true),
-		Port:            8081,
-		PortName:        "http-8081",
-		ServicePort:     81,
-		ServicePortName: "http-81",
+		PlatformBaseTrait: traitv1.PlatformBaseTrait{},
+		Name:              "test-container",
+		Auto:              pointer.Bool(false),
+		Expose:            pointer.Bool(true),
+		Port:              8081,
+		PortName:          "http-8081",
+		ServicePort:       81,
+		ServicePortName:   "http-81",
 	}
 	expected := map[string]interface{}{
-		"enabled":         true,
 		"auto":            false,
 		"expose":          true,
 		"port":            float64(8081),
 		"portName":        "http-8081",
 		"servicePort":     float64(81),
 		"servicePortName": "http-81",
-		"configuration": map[string]interface{}{
-			"name": "test-container",
-			"port": float64(8082),
-		},
+		"name":            "test-container",
 	}
 
 	propMap, err := ToPropertyMap(trait)
 
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, expected, propMap)
 }
 
@@ -130,13 +113,9 @@ func TestMigrateLegacyConfiguration(t *testing.T) {
 		"port":            float64(8081),
 		"portName":        "http-8081",
 		"servicePortName": "http-81",
-		"configuration": map[string]interface{}{
-			"auto":        true,
-			"expose":      true,
-			"name":        "test-container",
-			"port":        float64(8082),
-			"servicePort": float64(81),
-		},
+		"expose":          true,
+		"name":            "test-container",
+		"servicePort":     float64(81),
 	}
 	expected := map[string]interface{}{
 		"enabled":         true,
@@ -151,7 +130,7 @@ func TestMigrateLegacyConfiguration(t *testing.T) {
 
 	err := MigrateLegacyConfiguration(trait)
 
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, expected, trait)
 }
 
@@ -163,43 +142,34 @@ func TestMigrateLegacyConfiguration_invalidConfiguration(t *testing.T) {
 
 	err := MigrateLegacyConfiguration(trait)
 
-	assert.Error(t, err)
+	require.Error(t, err)
 }
 
 func TestToTrait(t *testing.T) {
 	config := map[string]interface{}{
-		"enabled":         true,
 		"auto":            false,
 		"expose":          true,
 		"port":            8081,
 		"portName":        "http-8081",
 		"servicePort":     81,
 		"servicePortName": "http-81",
-		"configuration": map[string]interface{}{
-			"name": "test-container",
-			"port": float64(8082),
-		},
+		"name":            "test-container",
 	}
 	expected := traitv1.ContainerTrait{
-		Trait: traitv1.Trait{
-			Enabled: pointer.Bool(true),
-			Configuration: configurationFromMap(t, map[string]interface{}{
-				"name": "test-container",
-				"port": 8082,
-			}),
-		},
-		Auto:            pointer.Bool(false),
-		Expose:          pointer.Bool(true),
-		Port:            8081,
-		PortName:        "http-8081",
-		ServicePort:     81,
-		ServicePortName: "http-81",
+		PlatformBaseTrait: traitv1.PlatformBaseTrait{},
+		Name:              "test-container",
+		Auto:              pointer.Bool(false),
+		Expose:            pointer.Bool(true),
+		Port:              8081,
+		PortName:          "http-8081",
+		ServicePort:       81,
+		ServicePortName:   "http-81",
 	}
 
 	trait := traitv1.ContainerTrait{}
 	err := ToTrait(config, &trait)
 
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, expected, trait)
 }
 
@@ -221,7 +191,7 @@ func TestSameTraits(t *testing.T) {
 		}
 
 		ok, err := PipesHaveSameTraits(oldKlb, newKlb)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.True(t, ok)
 	})
 
@@ -250,7 +220,7 @@ func TestSameTraits(t *testing.T) {
 		}
 
 		ok, err := PipesHaveSameTraits(oldKlb, newKlb)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.True(t, ok)
 	})
 
@@ -279,7 +249,7 @@ func TestSameTraits(t *testing.T) {
 		}
 
 		ok, err := PipesHaveSameTraits(oldKlb, newKlb)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.False(t, ok)
 	})
 
@@ -304,7 +274,7 @@ func TestSameTraits(t *testing.T) {
 		}
 
 		ok, err := PipesHaveSameTraits(oldKlb, newKlb)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.True(t, ok)
 	})
 
@@ -325,7 +295,7 @@ func TestSameTraits(t *testing.T) {
 		}
 
 		ok, err := PipesHaveSameTraits(oldKlb, newKlb)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.True(t, ok)
 	})
 
@@ -350,7 +320,7 @@ func TestSameTraits(t *testing.T) {
 		}
 
 		ok, err := PipesHaveSameTraits(oldKlb, newKlb)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.False(t, ok)
 	})
 
@@ -371,7 +341,97 @@ func TestSameTraits(t *testing.T) {
 		}
 
 		ok, err := PipesHaveSameTraits(oldKlb, newKlb)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.False(t, ok)
 	})
 }
+
+func TestHasMathchingTraitsEmpty(t *testing.T) {
+	opt1 := Options{
+		"builder": {},
+		"camel": {
+			"runtimeVersion": "1.2.3",
+		},
+		"quarkus": {},
+	}
+	opt2 := Options{
+		"camel": {
+			"runtimeVersion": "1.2.3",
+		},
+	}
+	opt3 := Options{
+		"camel": {
+			"runtimeVersion": "1.2.3",
+		},
+	}
+	opt4 := Options{
+		"camel": {
+			"runtimeVersion": "3.2.1",
+		},
+	}
+	b1, err := HasMatchingTraits(opt1, opt2)
+	assert.Nil(t, err)
+	assert.True(t, b1)
+	b2, err := HasMatchingTraits(opt1, opt4)
+	assert.Nil(t, err)
+	assert.False(t, b2)
+	b3, err := HasMatchingTraits(opt2, opt3)
+	assert.Nil(t, err)
+	assert.True(t, b3)
+}
+
+func TestHasMathchingTraitsMissing(t *testing.T) {
+	opt1 := Options{}
+	opt2 := Options{
+		"camel": {
+			"properties": []string{"a=1"},
+		},
+	}
+	b1, err := HasMatchingTraits(opt1, opt2)
+	assert.Nil(t, err)
+	assert.True(t, b1)
+}
+
+func TestFromAnnotationsPlain(t *testing.T) {
+	meta := metav1.ObjectMeta{
+		Annotations: map[string]string{
+			"trait.camel.apache.org/trait.prop1": "hello1",
+			"trait.camel.apache.org/trait.prop2": "hello2",
+		},
+	}
+	opt, err := FromAnnotations(&meta)
+	require.NoError(t, err)
+	tt, ok := opt.Get("trait")
+	assert.True(t, ok)
+	assert.Equal(t, "hello1", tt["prop1"])
+	assert.Equal(t, "hello2", tt["prop2"])
+}
+
+func TestFromAnnotationsArray(t *testing.T) {
+	meta := metav1.ObjectMeta{
+		Annotations: map[string]string{
+			"trait.camel.apache.org/trait.prop1": "[hello,world]",
+			// The func should trim empty spaces as well
+			"trait.camel.apache.org/trait.prop2": "[\"hello=1\", \"world=2\"]",
+		},
+	}
+	opt, err := FromAnnotations(&meta)
+	require.NoError(t, err)
+	tt, ok := opt.Get("trait")
+	assert.True(t, ok)
+	assert.Equal(t, []string{"hello", "world"}, tt["prop1"])
+	assert.Equal(t, []string{"\"hello=1\"", "\"world=2\""}, tt["prop2"])
+}
+
+func TestFromAnnotationsArrayEmpty(t *testing.T) {
+	meta := metav1.ObjectMeta{
+		Annotations: map[string]string{
+			"trait.camel.apache.org/trait.prop": "[]",
+		},
+	}
+	opt, err := FromAnnotations(&meta)
+	require.NoError(t, err)
+	tt, ok := opt.Get("trait")
+	assert.True(t, ok)
+	assert.Equal(t, []string{}, tt["prop"])
+}
