@@ -23,6 +23,7 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
+	messaging "knative.dev/eventing/pkg/apis/messaging/v1"
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
@@ -266,7 +267,7 @@ func (c *Collection) GetServiceForIntegration(integration *v1.Integration) *core
 	})
 }
 
-// GetKnativeService returns a knative Service that matches the given function.
+// GetKnativeService returns a Knative Service that matches the given function.
 func (c *Collection) GetKnativeService(filter func(*serving.Service) bool) *serving.Service {
 	var retValue *serving.Service
 	c.VisitKnativeService(func(re *serving.Service) {
@@ -277,6 +278,28 @@ func (c *Collection) GetKnativeService(filter func(*serving.Service) bool) *serv
 	return retValue
 }
 
+// GetKnativeTrigger returns a Knative Trigger that matches the given function.
+func (c *Collection) GetKnativeTrigger(filter func(*eventing.Trigger) bool) *eventing.Trigger {
+	var retValue *eventing.Trigger
+	c.VisitKnativeTrigger(func(re *eventing.Trigger) {
+		if filter(re) {
+			retValue = re
+		}
+	})
+	return retValue
+}
+
+// GetKnativeSubscription returns a Knative channel Subscription that matches the given function.
+func (c *Collection) GetKnativeSubscription(filter func(subscription *messaging.Subscription) bool) *messaging.Subscription {
+	var retValue *messaging.Subscription
+	c.VisitKnativeSubscription(func(re *messaging.Subscription) {
+		if filter(re) {
+			retValue = re
+		}
+	})
+	return retValue
+}
+
 // VisitRoute executes the visitor function on all Route resources.
 func (c *Collection) VisitRoute(visitor func(*routev1.Route)) {
 	c.Visit(func(res runtime.Object) {
@@ -357,6 +380,15 @@ func (c *Collection) VisitKnativeTrigger(visitor func(trigger *eventing.Trigger)
 	})
 }
 
+// VisitKnativeSubscription executes the visitor function on all Knative channel Subscription resources.
+func (c *Collection) VisitKnativeSubscription(visitor func(trigger *messaging.Subscription)) {
+	c.Visit(func(res runtime.Object) {
+		if conv, ok := res.(*messaging.Subscription); ok {
+			visitor(conv)
+		}
+	})
+}
+
 // HasKnativeTrigger returns true if a Knative trigger respecting filter is found.
 func (c *Collection) HasKnativeTrigger(filter func(trigger *eventing.Trigger) bool) bool {
 	var retValue *bool
