@@ -39,12 +39,14 @@ import (
 	"k8s.io/client-go/kubernetes"
 	fakeclientset "k8s.io/client-go/kubernetes/fake"
 	clientscheme "k8s.io/client-go/kubernetes/scheme"
+	authorizationv1 "k8s.io/client-go/kubernetes/typed/authorization/v1"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/scale"
 	fakescale "k8s.io/client-go/scale/fake"
 	"k8s.io/client-go/testing"
 	controller "sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
+	"sigs.k8s.io/controller-runtime/pkg/client/interceptor"
 )
 
 // NewFakeClient ---.
@@ -111,10 +113,12 @@ func NewFakeClient(initObjs ...runtime.Object) (client.Client, error) {
 	})
 
 	return &FakeClient{
-		Client:    c,
-		Interface: clientset,
-		camel:     camelClientset,
-		scales:    &fakescaleclient,
+		Client:                 c,
+		Interface:              clientset,
+		camel:                  camelClientset,
+		scales:                 &fakescaleclient,
+		enabledKnativeServing:  true,
+		enabledKnativeEventing: true,
 	}, nil
 }
 
@@ -136,10 +140,17 @@ func filterObjects(scheme *runtime.Scheme, input []runtime.Object, filter func(g
 type FakeClient struct {
 	controller.Client
 	kubernetes.Interface
-	camel            *fakecamelclientset.Clientset
-	scales           *fakescale.FakeScaleClient
-	disabledGroups   []string
-	enabledOpenshift bool
+	camel                  *fakecamelclientset.Clientset
+	scales                 *fakescale.FakeScaleClient
+	disabledGroups         []string
+	enabledOpenshift       bool
+	enabledKnativeServing  bool
+	enabledKnativeEventing bool
+}
+
+func (c *FakeClient) Intercept(intercept *interceptor.Funcs) {
+	cw := c.Client.(controller.WithWatch) // nolint: forcetypeassert
+	c.Client = interceptor.NewClient(cw, *intercept)
 }
 
 func (c *FakeClient) AddReactor(verb, resource string, reaction testing.ReactionFunc) {
@@ -184,11 +195,29 @@ func (c *FakeClient) EnableOpenshiftDiscovery() {
 	c.enabledOpenshift = true
 }
 
+func (c *FakeClient) DisableKnativeServing() {
+	c.enabledKnativeServing = false
+}
+
+func (c *FakeClient) DisableKnativeEventing() {
+	c.enabledKnativeEventing = false
+}
+
+func (c *FakeClient) AuthorizationV1() authorizationv1.AuthorizationV1Interface {
+	return &FakeAuthorization{
+		AuthorizationV1Interface: c.Interface.AuthorizationV1(),
+		disabledGroups:           c.disabledGroups,
+		enabledOpenshift:         c.enabledOpenshift,
+	}
+}
+
 func (c *FakeClient) Discovery() discovery.DiscoveryInterface {
 	return &FakeDiscovery{
-		DiscoveryInterface: c.Interface.Discovery(),
-		disabledGroups:     c.disabledGroups,
-		enabledOpenshift:   c.enabledOpenshift,
+		DiscoveryInterface:     c.Interface.Discovery(),
+		disabledGroups:         c.disabledGroups,
+		enabledOpenshift:       c.enabledOpenshift,
+		enabledKnativeServing:  c.enabledKnativeServing,
+		enabledKnativeEventing: c.enabledKnativeEventing,
 	}
 }
 
@@ -202,12 +231,24 @@ func (c *FakeClient) ScalesClient() (scale.ScalesGetter, error) {
 	return c.scales, nil
 }
 
-type FakeDiscovery struct {
-	discovery.DiscoveryInterface
+type FakeAuthorization struct {
+	authorizationv1.AuthorizationV1Interface
 	disabledGroups   []string
 	enabledOpenshift bool
 }
 
+func (f *FakeAuthorization) SelfSubjectRulesReviews() authorizationv1.SelfSubjectRulesReviewInterface {
+	return f.AuthorizationV1Interface.SelfSubjectRulesReviews()
+}
+
+type FakeDiscovery struct {
+	discovery.DiscoveryInterface
+	disabledGroups         []string
+	enabledOpenshift       bool
+	enabledKnativeServing  bool
+	enabledKnativeEventing bool
+}
+
 func (f *FakeDiscovery) ServerResourcesForGroupVersion(groupVersion string) (*metav1.APIResourceList, error) {
 	// Normalize the fake discovery to behave like the real implementation when checking for openshift
 	if groupVersion == "image.openshift.io/v1" {
@@ -222,26 +263,33 @@ func (f *FakeDiscovery) ServerResourcesForGroupVersion(groupVersion string) (*me
 		}
 	}
 
-	// used to verify if knative is installed
-	if groupVersion == "serving.knative.dev/v1" && !util.StringSliceExists(f.disabledGroups, groupVersion) {
-		return &metav1.APIResourceList{
-			GroupVersion: "serving.knative.dev/v1",
-		}, nil
+	// used to verify if Knative Serving is installed
+	if f.enabledKnativeServing {
+		if groupVersion == "serving.knative.dev/v1" && !util.StringSliceExists(f.disabledGroups, groupVersion) {
+			return &metav1.APIResourceList{
+				GroupVersion: "serving.knative.dev/v1",
+			}, nil
+		}
 	}
-	if groupVersion == "eventing.knative.dev/v1" && !util.StringSliceExists(f.disabledGroups, groupVersion) {
-		return &metav1.APIResourceList{
-			GroupVersion: "eventing.knative.dev/v1",
-		}, nil
-	}
-	if groupVersion == "messaging.knative.dev/v1" && !util.StringSliceExists(f.disabledGroups, groupVersion) {
-		return &metav1.APIResourceList{
-			GroupVersion: "messaging.knative.dev/v1",
-		}, nil
-	}
-	if groupVersion == "messaging.knative.dev/v1beta1" && !util.StringSliceExists(f.disabledGroups, groupVersion) {
-		return &metav1.APIResourceList{
-			GroupVersion: "messaging.knative.dev/v1beta1",
-		}, nil
+
+	// used to verify if Knative Eventing is installed
+	if f.enabledKnativeEventing {
+		if groupVersion == "eventing.knative.dev/v1" && !util.StringSliceExists(f.disabledGroups, groupVersion) {
+			return &metav1.APIResourceList{
+				GroupVersion: "eventing.knative.dev/v1",
+			}, nil
+		}
+		if groupVersion == "messaging.knative.dev/v1" && !util.StringSliceExists(f.disabledGroups, groupVersion) {
+			return &metav1.APIResourceList{
+				GroupVersion: "messaging.knative.dev/v1",
+			}, nil
+		}
+		if groupVersion == "messaging.knative.dev/v1beta1" && !util.StringSliceExists(f.disabledGroups, groupVersion) {
+			return &metav1.APIResourceList{
+				GroupVersion: "messaging.knative.dev/v1beta1",
+			}, nil
+		}
 	}
+
 	return f.DiscoveryInterface.ServerResourcesForGroupVersion(groupVersion)
 }
